netapp_ontap.models.nvme_namespace_subsystem_map_subsystem API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nvme_namespace_subsystem_map_subsystem`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NvmeNamespaceSubsystemMapSubsystemSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NvmeNamespaceSubsystemMapSubsystem object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `comment: str GET POST`

    A configurable comment for the NVMe subsystem. Optional in POST.

  `hosts: List[ConsistencyGroupNvmeHost] GET POST`

    The NVMe hosts configured for access to the NVMe subsystem. Optional in POST.

  `links: SelfLink GET`

    The links field of the nvme_namespace_subsystem_map_subsystem.

  `name: str GET POST`

    The name of the NVMe subsystem. Once created, an NVMe subsystem cannot be renamed. Optional in POST.

    Example: subsystem1

  `os_type: str GET POST`

    The host operating system of the NVMe subsystem's hosts. Optional in POST.

    Valid choices:

    - aix
    - linux
    - vmware
    - windows
  `uuid: str GET POST`

    The unique identifier of the NVMe subsystem.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412